==> OpenViewerFX-6.6.14-sources.jar: org/jpedal/examples/viewer/gui/CheckNode.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2015 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * CheckNode.java
 * ---------------
 */

package org.jpedal.examples.viewer.gui;

import javax.swing.tree.DefaultMutableTreeNode;

public class CheckNode extends DefaultMutableTreeNode {

    protected boolean isSelected, isEnabled;
    private final Object text;

    public CheckNode(final Object userObject) {
        this(userObject, true, false);
    }

    public CheckNode(final Object userObject, final boolean allowsChildren
            , final boolean isSelected) {
        super(userObject, allowsChildren);
        this.isSelected = isSelected;

        text=userObject;
    }

    public Object getText() {
        return text;
    }

    public void setSelected(final boolean isSelected) {
        this.isSelected = isSelected;

    }

    public boolean isSelected() {
        return isSelected;
    }

    public void setEnabled(final boolean isEnabled) {
        this.isEnabled = isEnabled;

    }

    public boolean isEnabled() {
        return isEnabled;
    }
}

==> OpenViewerFX-7.9.26-sources.jar: org/jpedal/examples/viewer/gui/CheckNode.java <==
/*
 * ===========================================
 * Java Pdf Extraction Decoding Access Library
 * ===========================================
 *
 * Project Info:  http://www.idrsolutions.com
 * Help section for developers at http://www.idrsolutions.com/support/
 *
 * (C) Copyright 1997-2017 IDRsolutions and Contributors.
 *
 * This file is part of JPedal/JPDF2HTML5
 *
     This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


 *
 * ---------------
 * CheckNode.java
 * ---------------
 */

package org.jpedal.examples.viewer.gui;

import javax.swing.tree.DefaultMutableTreeNode;

public class CheckNode extends DefaultMutableTreeNode {

    protected boolean isSelected, isEnabled;
    private final String text;

    public CheckNode(final String userObject) {
        this(userObject, true, false);
    }

    public CheckNode(final String userObject, final boolean allowsChildren
            , final boolean isSelected) {
        super(userObject, allowsChildren);
        this.isSelected = isSelected;

        text=userObject;
    }

    public String getText() {
        return text;
    }

    public void setSelected(final boolean isSelected) {
        this.isSelected = isSelected;

    }

    public boolean isSelected() {
        return isSelected;
    }

    public void setEnabled(final boolean isEnabled) {
        this.isEnabled = isEnabled;

    }

    public boolean isEnabled() {
        return isEnabled;
    }
}
